==> gnome-recipes-1.6.2.tar.xz: gnome-recipes-1.6.2/data/chefs.db.h <==
#if 0

N_("I cook a lot, particularly Italian and Indian.")
N_("A Kuala Lumpur native, transplanted to San Francisco. I bake, I cook, I work on GNOME engagement stuff occasionally. Every now and then I travel between North America, Asia and Europe. Follow me @adeliabakes.")
N_("Adrià is originally from Barcelona, Spain.")
N_("Being from Strasbourg, Alexandre is knowledgeable about both Alsatian and French cuisine, but he's not afraid to experiment in other ones as well.")
N_("The nordic cuisine maestro.")
N_("He cooks with GTK+")
N_("Elvin lives in Istanbul.")
N_("Erusan is an American who has lived all over the country, loves GNOME, and enjoys cooking — primarily American, Asian, and Indian cuisine.")
N_("Georges is a vegan samurai, a GNOME contributor, and sometimes both.")
N_("My name is Fredrik Fyksen. I am from Norway, but live in Denmark. I like food, computers and music. You can read more about me at <a href=\"https://www.fyksen.me/\">fyksen.me</a>.")
N_("Ray is a Desktop Software Engineer at Red Hat and vegetarian who occasionally enjoys cooking.")
N_("Dad with a sysadmin problem/hobby")
N_("Just Link.")
N_("Matthias is a manager in the Desktop team at Red Hat. He likes to cook as much as he likes to code.")
N_("Matthew is a vegan and a Computer Science student who loves FOSS.")
N_("I'm cooking from time to time and started to add recipes here.")
N_("Artist, Computer Scientist, Translator.")
N_("I love cooking and learning.")
N_("Another designer who loves to cook")
N_("GNOME contributor and cook")
N_("Artist, Computer Scientist, Traveller.")
N_("I love cooking. :)")
N_("Aviation, making stuff, in Finland.")


#endif

==> gnome-recipes_2.0.0.orig.tar.xz: gnome-recipes-2.0.0/data/chefs.db.h <==
#if 0

N_("I cook a lot, particularly Italian and Indian.")
N_("A Kuala Lumpur native, transplanted to San Francisco. I bake, I cook, I work on GNOME engagement stuff occasionally. Every now and then I travel between North America, Asia and Europe. Follow me @adeliabakes.")
N_("Adrià is originally from Barcelona, Spain.")
N_("Being from Strasbourg, Alexandre is knowledgeable about both Alsatian and French cuisine, but he's not afraid to experiment in other ones as well.")
N_("The nordic cuisine maestro.")
N_("I love to blend and juice.")
N_("He cooks with GTK+")
N_("Elvin lives in Istanbul.")
N_("Erusan is an American who has lived all over the country, loves GNOME, and enjoys cooking — primarily American, Asian, and Indian cuisine.")
N_("Georges is a vegan samurai, a GNOME contributor, and sometimes both.")
N_("My name is Fredrik Fyksen. I am from Norway, but live in Denmark. I like food, computers and music. You can read more about me at <a href=\"https://www.fyksen.me/\">fyksen.me</a>.")
N_("Ray is a Desktop Software Engineer at Red Hat and vegetarian who occasionally enjoys cooking.")
N_("Dad with a sysadmin problem/hobby")
N_("Just Link.")
N_("Matthias is a manager in the Desktop team at Red Hat. He likes to cook as much as he likes to code.")
N_("Matthew is a vegan and a Computer Science student who loves FOSS.")
N_("I'm cooking from time to time and started to add recipes here.")
N_("Artist, Computer Scientist, Translator.")
N_("I love cooking and learning.")
N_("Another designer who loves to cook")
N_("Computer science student and aspiring software developer.")
N_("<a href=\"https://krourke.org\">https://krourke.org</a>")
N_("GNOME contributor and cook")
N_("Artist, Computer Scientist, Traveller.")
N_("I love cooking. :)")
N_("Aviation, making stuff, in Finland.")
N_("Just another chef")


#endif
